Risk Models
===========

This section documents all available cardiovascular disease risk prediction models in PyCVDRisk.

Primary Prevention Models
-------------------------

SCORE2
~~~~~~

.. automodule:: cvd_risk.models.score2
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.score2.SCORE2
   :members:
   :special-members:

SCORE
~~~~~

.. automodule:: cvd_risk.models.score
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.score.SCORE
   :members:
   :special-members:

ASCVD
~~~~~

.. automodule:: cvd_risk.models.ascvd
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.ascvd.ASCVD
   :members:
   :special-members:

Framingham
~~~~~~~~~~~

.. automodule:: cvd_risk.models.framingham
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.framingham.Framingham
   :members:
   :special-members:

QRISK2
~~~~~~

.. automodule:: cvd_risk.models.qrisk2
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.qrisk2.QRISK2
   :members:
   :special-members:

QRISK3
~~~~~~

.. automodule:: cvd_risk.models.qrisk3
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.qrisk3.QRISK3
   :members:
   :special-members:

WHO CVD
~~~~~~~

.. automodule:: cvd_risk.models.who
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.who.WHO
   :members:
   :special-members:

Globorisk
~~~~~~~~~

.. automodule:: cvd_risk.models.globorisk
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.globorisk.Globorisk
   :members:
   :special-members:

PREVENT
~~~~~~~

.. automodule:: cvd_risk.models.prevent
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.prevent.Prevent
   :members:
   :special-members:

Secondary Prevention Models
---------------------------

SMART2
~~~~~~

.. automodule:: cvd_risk.models.smart2
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.smart2.SMART2
   :members:
   :special-members:

SMART-REACH
~~~~~~~~~~~

.. automodule:: cvd_risk.models.smartreach
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.smartreach.SMART_REACH
   :members:
   :special-members:

Diabetes-Specific Models
------------------------

DIAL2
~~~~~

.. automodule:: cvd_risk.models.dial2
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.dial2.DIAL2
   :members:
   :special-members:

SCORE2-DM
~~~~~~~~~

.. automodule:: cvd_risk.models.score2dm
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.score2dm.SCORE2DM
   :members:
   :special-members:

CKD-Specific Models
-------------------

SCORE2-CKD
~~~~~~~~~~

.. automodule:: cvd_risk.models.score2ckd
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.score2ckd.SCORE2CKD
   :members:
   :special-members:

SCORE2-OP
~~~~~~~~~

.. automodule:: cvd_risk.models.score2op
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.score2op.SCORE2OP
   :members:
   :special-members:

Region-Specific Models
----------------------

ASSIGN
~~~~~~

.. automodule:: cvd_risk.models.assign
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.assign.ASSIGN
   :members:
   :special-members:

SCORE2-Asia CKD
~~~~~~~~~~~~~~~

.. automodule:: cvd_risk.models.score2asia
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.score2asia.SCORE2AsiaCKD
   :members:
   :special-members:

Lifetime Risk Models
--------------------

LifeCVD2
~~~~~~~~

.. automodule:: cvd_risk.models.lifecvd2
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.lifecvd2.LifeCVD2
   :members:
   :special-members:

Acute Coronary Syndrome Models
------------------------------

GRACE2
~~~~~~

.. automodule:: cvd_risk.models.grace2
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.grace2.GRACE2
   :members:
   :special-members:

TIMI
~~~~

.. automodule:: cvd_risk.models.timi
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.timi.TIMI
   :members:
   :special-members:

Emergency Department Models
---------------------------

EDACS
~~~~~

.. automodule:: cvd_risk.models.edacs
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.edacs.EDACS
   :members:
   :special-members:

HEART
~~~~~

.. automodule:: cvd_risk.models.heart
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk.models.heart.HEART
   :members:
   :special-members:

